==> add-to-any.1.7.7.zip: add-to-any/addtoany.services.php <==
<?php

$A2A_SHARE_SAVE_services = array(

	"facebook" => array(
		"name" => "Facebook",
		"icon" => "facebook",
		"color" => "3B5998",
	),
	"twitter" => array(
		"name" => "Twitter",
		"icon" => "twitter",
		"color" => "55ACEE",
	),
	"google_plus" => array(
		"name" => "Google+",
		"icon" => "google_plus",
		"color" => "DD4B39",
	),
	"pinterest" => array(
		"name" => "Pinterest",
		"icon" => "pinterest",
		"color" => "BD081C",
	),
	"email" => array(
		"name" => "Email",
		"icon" => "email",
		"color" => "0166FF",
	),
	"tumblr" => array(
		"name" => "Tumblr",
		"icon" => "tumblr",
		"color" => "35465C",
	),
	"reddit" => array(
		"name" => "Reddit",
		"icon" => "reddit",
		"color" => "ff4500",
	),
	"linkedin" => array(
		"name" => "LinkedIn",
		"icon" => "linkedin",
		"color" => "007BB5",
	),
	"whatsapp" => array(
		"name" => "WhatsApp",
		"icon" => "whatsapp",
		"color" => "12AF0A",
	),
	"aim" => array(
		"name" => "AIM",
		"icon" => "aim",
		"color" => "00C2FF",
	),
	"amazon_wish_list" => array(
		"name" => "Amazon Wish List",
		"icon" => "amazon",
		"color" => "F90",
	),
	"aol_mail" => array(
		"name" => "AOL Mail",
		"icon" => "aol",
		"color" => "2A2A2A",
	),
	"app_net" => array(
		"name" => "App.net",
		"icon" => "app_net",
		"color" => "5D5D5D",
	),
	"baidu" => array(
		"name" => "Baidu",
		"icon" => "baidu",
		"color" => "2319DC",
	),
	"balatarin" => array(
		"name" => "Balatarin",
		"icon" => "balatarin",
		"color" => "079948",
	),
	"bibsonomy" => array(
		"name" => "BibSonomy",
		"icon" => "bibsonomy",
		"color" => "2A2A2A",
	),
	"bitty_browser" => array(
		"name" => "Bitty Browser",
		"icon" => "bitty",
		"color" => "999",
	),
	"blinklist" => array(
		"name" => "Blinklist",
		"icon" => "blinklist",
		"color" => "3D3C3B",
	),
	"blogger_post" => array(
		"name" => "Blogger Post",
		"icon" => "blogger",
		"color" => "FDA352",
	),
	"blogmarks" => array(
		"name" => "BlogMarks",
		"icon" => "blogmarks",
		"color" => "535353",
	),
	"bookmarks_fr" => array(
		"name" => "Bookmarks.fr",
		"icon" => "bookmarks_fr",
		"color" => "96C044",
	),
	"box_net" => array(
		"name" => "Box.net",
		"icon" => "box",
		"color" => "1A74B0",
	),
	"buddymarks" => array(
		"name" => "BuddyMarks",
		"icon" => "buddymarks",
		"color" => "96C044",
	),
	"buffer" => array(
		"name" => "Buffer",
		"icon" => "buffer",
		"color" => "2A2A2A",
	),
	"care2_news" => array(
		"name" => "Care2 News",
		"icon" => "care2",
		"color" => "6EB43F",
	),
	"citeulike" => array(
		"name" => "CiteULike",
		"icon" => "citeulike",
		"color" => "2781CD",
	),
	"copy_link" => array(
		"name" => "Copy Link",
		"icon" => "link",
		"color" => "0166FF",
	),
	"delicious" => array(
		"name" => "Delicious",
		"icon" => "delicious",
		"color" => "39F",
	),
	"design_float" => array(
		"name" => "Design Float",
		"icon" => "designfloat",
		"color" => "8AC8FF",
	),
	"diary_ru" => array(
		"name" => "Diary.Ru",
		"icon" => "diary_ru",
		"color" => "912D31",
	),
	"diaspora" => array(
		"name" => "Diaspora",
		"icon" => "diaspora",
		"color" => "2E3436",
	),
	"digg" => array(
		"name" => "Digg",
		"icon" => "digg",
		"color" => "2A2A2A",
	),
	"dihitt" => array(
		"name" => "diHITT",
		"icon" => "dihitt",
		"color" => "FF6300",
	),
	"diigo" => array(
		"name" => "Diigo",
		"icon" => "diigo",
		"color" => "4A8BCA",
	),
	"douban" => array(
		"name" => "Douban",
		"icon" => "douban",
		"color" => "071",
	),
	"draugiem" => array(
		"name" => "Draugiem",
		"icon" => "draugiem",
		"color" => "F60",
	),
	"dzone" => array(
		"name" => "DZone",
		"icon" => "dzone",
		"color" => "82C251",
	),
	"evernote" => array(
		"name" => "Evernote",
		"icon" => "evernote",
		"color" => "8BE056",
	),
	"facebook_messenger" => array(
		"name" => "Facebook Messenger",
		"icon" => "facebook_messenger",
		"color" => "0084FF",
	),
	"fark" => array(
		"name" => "Fark",
		"icon" => "fark",
		"color" => "555",
	),
	"flipboard" => array(
		"name" => "Flipboard",
		"icon" => "flipboard",
		"color" => "C00",
	),
	"folkd" => array(
		"name" => "Folkd",
		"icon" => "folkd",
		"color" => "0F70B2",
	),
	"google_bookmarks" => array(
		"name" => "Google Bookmarks",
		"icon" => "google",
		"color" => "4285F4",
	),
	"google_classroom" => array(
		"name" => "Google Classroom",
		"icon" => "google_classroom",
		"color" => "FFC112",
	),
	"google_gmail" => array(
		"name" => "Google Gmail",
		"icon" => "gmail",
		"color" => "DD5347",
	),
	"hacker_news" => array(
		"name" => "Hacker News",
		"icon" => "y18",
		"color" => "F60",
	),
	"hatena" => array(
		"name" => "Hatena",
		"icon" => "hatena",
		"color" => "00A6DB",
	),
	"instapaper" => array(
		"name" => "Instapaper",
		"icon" => "instapaper",
		"color" => "2A2A2A",
	),
	"jamespot" => array(
		"name" => "Jamespot",
		"icon" => "jamespot",
		"color" => "FF9E2C",
	),
	"kakao" => array(
		"name" => "Kakao",
		"icon" => "kakao",
		"color" => "FCB700",
	),
	"kik" => array(
		"name" => "Kik",
		"icon" => "kik",
		"color" => "2A2A2A",
	),
	"kindle_it" => array(
		"name" => "Kindle It",
		"icon" => "kindle",
		"color" => "2A2A2A",
	),
	"known" => array(
		"name" => "Known",
		"icon" => "known",
		"color" => "2A2A2A",
	),
	"line" => array(
		"name" => "Line",
		"icon" => "line",
		"color" => "00C300",
	),
	"livejournal" => array(
		"name" => "LiveJournal",
		"icon" => "livejournal",
		"color" => "113140",
	),
	"mail_ru" => array(
		"name" => "Mail.Ru",
		"icon" => "mail_ru",
		"color" => "356FAC",
	),
	"mendeley" => array(
		"name" => "Mendeley",
		"icon" => "mendeley",
		"color" => "A70805",
	),
	"meneame" => array(
		"name" => "Meneame",
		"icon" => "meneame",
		"color" => "FF7D12",
	),
	"mixi" => array(
		"name" => "Mixi",
		"icon" => "mixi",
		"color" => "D1AD5A",
	),
	"myspace" => array(
		"name" => "MySpace",
		"icon" => "myspace",
		"color" => "2A2A2A",
	),
	"netlog" => array(
		"name" => "Netlog",
		"icon" => "netlog",
		"color" => "2A2A2A",
	),
	"netvouz" => array(
		"name" => "Netvouz",
		"icon" => "netvouz",
		"color" => "6C3",
	),
	"newsvine" => array(
		"name" => "NewsVine",
		"icon" => "newsvine",
		"color" => "055D00",
	),
	"nujij" => array(
		"name" => "NUjij",
		"icon" => "nujij",
		"color" => "D40000",
	),
	"odnoklassniki" => array(
		"name" => "Odnoklassniki",
		"icon" => "odnoklassniki",
		"color" => "F2720C",
	),
	"oknotizie" => array(
		"name" => "Oknotizie",
		"icon" => "oknotizie",
		"color" => "88D32D",
	),
	"outlook_com" => array(
		"name" => "Outlook.com",
		"icon" => "outlook_com",
		"color" => "0072C6",
	),
	"pinboard" => array(
		"name" => "Pinboard",
		"icon" => "pinboard",
		"color" => "1341DE",
	),
	"plurk" => array(
		"name" => "Plurk",
		"icon" => "plurk",
		"color" => "CF682F",
	),
	"pocket" => array(
		"name" => "Pocket",
		"icon" => "pocket",
		"color" => "EE4056",
	),
	"polyvore" => array(
		"name" => "Polyvore",
		"icon" => "polyvore",
		"color" => "2A2A2A",
	),
	"print" => array(
		"name" => "Print",
		"icon" => "print",
		"color" => "0166FF",
	),
	"printfriendly" => array(
		"name" => "PrintFriendly",
		"icon" => "printfriendly",
		"color" => "6D9F00",
	),
	"protopage_bookmarks" => array(
		"name" => "Protopage Bookmarks",
		"icon" => "protopage",
		"color" => "413FFF",
	),
	"pusha" => array(
		"name" => "Pusha",
		"icon" => "pusha",
		"color" => "0072B8",
	),
	"qzone" => array(
		"name" => "Qzone",
		"icon" => "qzone",
		"color" => "2B82D9",
	),
	"rediff" => array(
		"name" => "Rediff MyPage",
		"icon" => "rediff",
		"color" => "D20000",
	),
	"renren" => array(
		"name" => "Renren",
		"icon" => "renren",
		"color" => "005EAC",
	),
	"segnalo" => array(
		"name" => "Segnalo",
		"icon" => "segnalo",
		"color" => "FF6500",
	),
	"sina_weibo" => array(
		"name" => "Sina Weibo",
		"icon" => "sina_weibo",
		"color" => "E6162D",
	),
	"sitejot" => array(
		"name" => "SiteJot",
		"icon" => "sitejot",
		"color" => "FFC808",
	),
	"skype" => array(
		"name" => "Skype",
		"icon" => "skype",
		"color" => "00AFF0",
	),
	"slashdot" => array(
		"name" => "Slashdot",
		"icon" => "slashdot",
		"color" => "004242",
	),
	"sms" => array(
		"name" => "SMS",
		"icon" => "sms",
		"color" => "6CBE45",
	),
	"stumbleupon" => array(
		"name" => "StumbleUpon",
		"icon" => "stumbleupon",
		"color" => "EF4E23",
	),
	"stumpedia" => array(
		"name" => "Stumpedia",
		"icon" => "stumpedia",
		"color" => "FFC808",
	),
	"svejo" => array(
		"name" => "Svejo",
		"icon" => "svejo",
		"color" => "5BD428",
	),
	"symbaloo_feeds" => array(
		"name" => "Symbaloo Feeds",
		"icon" => "symbaloo",
		"color" => "6DA8F7",
	),
	"telegram" => array(
		"name" => "Telegram",
		"icon" => "telegram",
		"color" => "2CA5E0",
	),
	"trello" => array(
		"name" => "Trello",
		"icon" => "trello",
		"color" => "0079BF",
	),
	"tuenti" => array(
		"name" => "Tuenti",
		"icon" => "tuenti",
		"color" => "0075C9",
	),
	"twiddla" => array(
		"name" => "Twiddla",
		"icon" => "twiddla",
		"color" => "2A2A2A",
	),
	"typepad_post" => array(
		"name" => "TypePad Post",
		"icon" => "typepad",
		"color" => "D2DE61",
	),
	"viadeo" => array(
		"name" => "Viadeo",
		"icon" => "viadeo",
		"color" => "2A2A2A",
	),
	"viber" => array(
		"name" => "Viber",
		"icon" => "viber",
		"color" => "7C529E",
	),
	"vk" => array(
		"name" => "VK",
		"icon" => "vk",
		"color" => "587EA3",
	),
	"wanelo" => array(
		"name" => "Wanelo",
		"icon" => "wanelo",
		"color" => "9cb092",
	),
	"webnews" => array(
		"name" => "Webnews",
		"icon" => "webnews",
		"color" => "CC2512",
	),
	"wechat" => array(
		"name" => "WeChat",
		"icon" => "wechat",
		"color" => "7BB32E",
	),
	"wordpress" => array(
		"name" => "WordPress",
		"icon" => "wordpress",
		"color" => "464646",
	),
	"wykop" => array(
		"name" => "Wykop",
		"icon" => "wykop",
		"color" => "367DA9",
	),
	"xing" => array(
		"name" => "XING",
		"icon" => "xing",
		"color" => "165B66",
	),
	"yahoo_bookmarks" => array(
		"name" => "Yahoo Bookmarks",
		"icon" => "yahoo",
		"color" => "400090",
	),
	"yahoo_mail" => array(
		"name" => "Yahoo Mail",
		"icon" => "yahoo",
		"color" => "400090",
	),
	"yahoo_messenger" => array(
		"name" => "Yahoo Messenger",
		"icon" => "yim",
		"color" => "400090",
	),
	"yoolink" => array(
		"name" => "Yoolink",
		"icon" => "yoolink",
		"color" => "A2C538",
	),
	"youmob" => array(
		"name" => "YouMob",
		"icon" => "youmob",
		"color" => "3B599D",
	),
	"yummly" => array(
		"name" => "Yummly",
		"icon" => "yummly",
		"color" => "E16120",
	),

);

$A2A_FOLLOW_services = array(
	
	'facebook' => array( 
		'name' => 'Facebook', 
		'href' => 'https://www.facebook.com/${id}',	
		'icon' => 'facebook',
		'color' => '3B5998',
	),
	'twitter' => array( 
		'name' => 'Twitter', 
		'href' => 'https://twitter.com/${id}',	
		'icon' => 'twitter',
		'color' => '55ACEE',
	),
	'instagram' => array( 
		'name' => 'Instagram', 
		'href' => 'https://www.instagram.com/${id}',	
		'icon' => 'instagram',
		'color' => 'E4405F',
	),
	'pinterest' => array( 
		'name' => 'Pinterest', 
		'href' => 'https://www.pinterest.com/${id}',	
		'icon' => 'pinterest',
		'color' => 'BD081C',
	),
	'behance' => array( 
		'name' => 'Behance', 
		'href' => 'https://www.behance.net/${id}',	
		'icon' => 'behance',
		'color' => '007EFF',
	),
	'flickr' => array( 
		'name' => 'Flickr', 
		'href' => 'https://www.flickr.com/photos/${id}',	
		'icon' => 'flickr',
		'color' => 'FF0084',
	),
	'foursquare' => array( 
		'name' => 'Foursquare', 
		'href' => 'https://foursquare.com/${id}',	
		'icon' => 'foursquare',
		'color' => 'F94877',
	),
	'github' => array( 
		'name' => 'GitHub', 
		'href' => 'https://github.com/${id}',	
		'icon' => 'github',
		'color' => '2A2A2A',
	),
	'google_plus' => array( 
		'name' => 'Google+', 
		'href' => 'https://plus.google.com/${id}',	
		'icon' => 'google_plus',
		'color' => 'DD4B39',
	),
	'linkedin' => array( 
		'name' => 'LinkedIn', 
		'href' => 'https://www.linkedin.com/in/${id}',	
		'icon' => 'linkedin',
		'color' => '007BB5',
	),
	'linkedin_company' => array( 
		'name' => 'LinkedIn Company', 
		'href' => 'https://www.linkedin.com/company/${id}',	
		'icon' => 'linkedin',
		'color' => '007BB5',
	),
	'snapchat' => array( 
		'name' => 'Snapchat', 
		'href' => 'https://www.snapchat.com/add/${id}',	
		'icon' => 'snapchat',
		'color' => '',
	),
	'tumblr' => array( 
		'name' => 'Tumblr', 
		'href' => 'http://${id}.tumblr.com',	
		'icon' => 'tumblr',
		'color' => '35465C',
	),
	'vimeo' => array( 
		'name' => 'Vimeo', 
		'href' => 'https://vimeo.com/${id}',	
		'icon' => 'vimeo',
		'color' => '1AB7EA',
	),
	'youtube' => array( 
		'name' => 'YouTube', 
		'href' => 'https://www.youtube.com/user/${id}',	
		'icon' => 'youtube',
		'color' => 'CD201F',
	),
	'youtube_channel' => array( 
		'name' => 'YouTube Channel', 
		'href' => 'https://www.youtube.com/channel/${id}',	
		'icon' => 'youtube',
		'color' => 'CD201F',
	),
	'feed' => array( 
		'name' => 'RSS Feed', 
		'href' => 'http://www.example.com/feed/',
		'icon' => 'feed',
		'color' => 'e3702d',
	),
	
);

==> add-to-any.1.8.4.zip: add-to-any/addtoany.services.php <==
<?php

$A2A_SHARE_SAVE_services = array(

	"facebook" => array(
		"name" => "Facebook",
		"icon" => "facebook",
		"color" => "1877F2",
	),
	"twitter" => array(
		"name" => "Twitter",
		"icon" => "twitter",
		"color" => "1D9BF0",
	),
	"pinterest" => array(
		"name" => "Pinterest",
		"icon" => "pinterest",
		"color" => "BD081C",
	),
	"email" => array(
		"name" => "Email",
		"icon" => "email",
		"color" => "0166FF",
	),
	"tumblr" => array(
		"name" => "Tumblr",
		"icon" => "tumblr",
		"color" => "35465C",
	),
	"reddit" => array(
		"name" => "Reddit",
		"icon" => "reddit",
		"color" => "ff4500",
	),
	"linkedin" => array(
		"name" => "LinkedIn",
		"icon" => "linkedin",
		"color" => "007BB5",
	),
	"whatsapp" => array(
		"name" => "WhatsApp",
		"icon" => "whatsapp",
		"color" => "12AF0A",
	),
	"amazon_wish_list" => array(
		"name" => "Amazon Wish List",
		"icon" => "amazon",
		"color" => "F90",
	),
	"aol_mail" => array(
		"name" => "AOL Mail",
		"icon" => "aol",
		"color" => "2A2A2A",
	),
	"balatarin" => array(
		"name" => "Balatarin",
		"icon" => "balatarin",
		"color" => "079948",
	),
	"bibsonomy" => array(
		"name" => "BibSonomy",
		"icon" => "bibsonomy",
		"color" => "2A2A2A",
	),
	"bitty_browser" => array(
		"name" => "Bitty Browser",
		"icon" => "bitty",
		"color" => "999",
	),
	"blogger" => array(
		"name" => "Blogger",
		"icon" => "blogger",
		"color" => "FDA352",
	),
	"blogmarks" => array(
		"name" => "BlogMarks",
		"icon" => "blogmarks",
		"color" => "535353",
	),
	"bookmarks_fr" => array(
		"name" => "Bookmarks.fr",
		"icon" => "bookmarks_fr",
		"color" => "96C044",
	),
	"box_net" => array(
		"name" => "Box.net",
		"icon" => "box",
		"color" => "1A74B0",
	),
	"buffer" => array(
		"name" => "Buffer",
		"icon" => "buffer",
		"color" => "2A2A2A",
	),
	"care2_news" => array(
		"name" => "Care2 News",
		"icon" => "care2",
		"color" => "6EB43F",
	),
	"citeulike" => array(
		"name" => "CiteULike",
		"icon" => "citeulike",
		"color" => "2781CD",
	),
	"copy_link" => array(
		"name" => "Copy Link",
		"icon" => "link",
		"color" => "0166FF",
	),
	"design_float" => array(
		"name" => "Design Float",
		"icon" => "designfloat",
		"color" => "8AC8FF",
	),
	"diary_ru" => array(
		"name" => "Diary.Ru",
		"icon" => "diary_ru",
		"color" => "912D31",
	),
	"diaspora" => array(
		"name" => "Diaspora",
		"icon" => "diaspora",
		"color" => "2E3436",
	),
	"digg" => array(
		"name" => "Digg",
		"icon" => "digg",
		"color" => "2A2A2A",
	),
	"diigo" => array(
		"name" => "Diigo",
		"icon" => "diigo",
		"color" => "4A8BCA",
	),
	"douban" => array(
		"name" => "Douban",
		"icon" => "douban",
		"color" => "071",
	),
	"draugiem" => array(
		"name" => "Draugiem",
		"icon" => "draugiem",
		"color" => "F60",
	),
	"dzone" => array(
		"name" => "DZone",
		"icon" => "dzone",
		"color" => "82C251",
	),
	"evernote" => array(
		"name" => "Evernote",
		"icon" => "evernote",
		"color" => "00A82D",
	),
	"fark" => array(
		"name" => "Fark",
		"icon" => "fark",
		"color" => "555",
	),
	"flipboard" => array(
		"name" => "Flipboard",
		"icon" => "flipboard",
		"color" => "C00",
	),
	"folkd" => array(
		"name" => "Folkd",
		"icon" => "folkd",
		"color" => "0F70B2",
	),
	"google_gmail" => array(
		"name" => "Gmail",
		"icon" => "gmail",
		"color" => "DD5347",
	),
	"google_bookmarks" => array(
		"name" => "Google Bookmarks",
		"icon" => "google",
		"color" => "4285F4",
	),
	"google_classroom" => array(
		"name" => "Google Classroom",
		"icon" => "google_classroom",
		"color" => "FFC112",
	),
	"hacker_news" => array(
		"name" => "Hacker News",
		"icon" => "y18",
		"color" => "F60",
	),
	"hatena" => array(
		"name" => "Hatena",
		"icon" => "hatena",
		"color" => "00A6DB",
	),
	"houzz" => array(
		"name" => "Houzz",
		"icon" => "houzz",
		"color" => "7AC143",
	),
	"instapaper" => array(
		"name" => "Instapaper",
		"icon" => "instapaper",
		"color" => "2A2A2A",
	),
	"kakao" => array(
		"name" => "Kakao",
		"icon" => "kakao",
		"color" => "FCB700",
	),
	"kik" => array(
		"name" => "Kik",
		"icon" => "kik",
		"color" => "2A2A2A",
	),
	"known" => array(
		"name" => "Known",
		"icon" => "known",
		"color" => "2A2A2A",
	),
	"line" => array(
		"name" => "Line",
		"icon" => "line",
		"color" => "00C300",
	),
	"livejournal" => array(
		"name" => "LiveJournal",
		"icon" => "livejournal",
		"color" => "113140",
	),
	"mail_ru" => array(
		"name" => "Mail.Ru",
		"icon" => "mail_ru",
		"color" => "356FAC",
	),
	"mastodon" => array(
		"name" => "Mastodon",
		"icon" => "mastodon",
		"color" => "2b90d9",
	),
	"mendeley" => array(
		"name" => "Mendeley",
		"icon" => "mendeley",
		"color" => "A70805",
	),
	"meneame" => array(
		"name" => "Meneame",
		"icon" => "meneame",
		"color" => "FF7D12",
	),
	"facebook_messenger" => array(
		"name" => "Messenger",
		"icon" => "facebook_messenger",
		"color" => "0084FF",
	),
	"mewe" => array(
		"name" => "MeWe",
		"icon" => "mewe",
		"color" => "007DA1",
	),
	"mixi" => array(
		"name" => "Mixi",
		"icon" => "mixi",
		"color" => "D1AD5A",
	),
	"myspace" => array(
		"name" => "MySpace",
		"icon" => "myspace",
		"color" => "2A2A2A",
	),
	"netvouz" => array(
		"name" => "Netvouz",
		"icon" => "netvouz",
		"color" => "6C3",
	),
	"odnoklassniki" => array(
		"name" => "Odnoklassniki",
		"icon" => "odnoklassniki",
		"color" => "F2720C",
	),
	"outlook_com" => array(
		"name" => "Outlook.com",
		"icon" => "outlook_com",
		"color" => "0072C6",
	),
	"papaly" => array(
		"name" => "Papaly",
		"icon" => "papaly",
		"color" => "3AC0F6",
	),
	"pinboard" => array(
		"name" => "Pinboard",
		"icon" => "pinboard",
		"color" => "1341DE",
	),
	"plurk" => array(
		"name" => "Plurk",
		"icon" => "plurk",
		"color" => "CF682F",
	),
	"pocket" => array(
		"name" => "Pocket",
		"icon" => "pocket",
		"color" => "EE4056",
	),
	"print" => array(
		"name" => "Print",
		"icon" => "print",
		"color" => "0166FF",
	),
	"printfriendly" => array(
		"name" => "PrintFriendly",
		"icon" => "printfriendly",
		"color" => "6D9F00",
	),
	"protopage_bookmarks" => array(
		"name" => "Protopage Bookmarks",
		"icon" => "protopage",
		"color" => "413FFF",
	),
	"pusha" => array(
		"name" => "Pusha",
		"icon" => "pusha",
		"color" => "0072B8",
	),
	"kindle_it" => array(
		"name" => "Push to Kindle",
		"icon" => "kindle",
		"color" => "2A2A2A",
	),
	"qzone" => array(
		"name" => "Qzone",
		"icon" => "qzone",
		"color" => "2B82D9",
	),
	"rediff" => array(
		"name" => "Rediff MyPage",
		"icon" => "rediff",
		"color" => "D20000",
	),
	"refind" => array(
		"name" => "Refind",
		"icon" => "refind",
		"color" => "1492ef",
	),
	"renren" => array(
		"name" => "Renren",
		"icon" => "renren",
		"color" => "005EAC",
	),
	"sina_weibo" => array(
		"name" => "Sina Weibo",
		"icon" => "sina_weibo",
		"color" => "E6162D",
	),
	"sitejot" => array(
		"name" => "SiteJot",
		"icon" => "sitejot",
		"color" => "FFC808",
	),
	"skype" => array(
		"name" => "Skype",
		"icon" => "skype",
		"color" => "00AFF0",
	),
	"slashdot" => array(
		"name" => "Slashdot",
		"icon" => "slashdot",
		"color" => "004242",
	),
	"sms" => array(
		"name" => "SMS",
		"icon" => "sms",
		"color" => "6CBE45",
	),
	"snapchat" => array(
		"name" => "Snapchat",
		"icon" => "snapchat",
		"color" => "2A2A2A",
	),
	"stocktwits" => array(
		"name" => "StockTwits",
		"icon" => "stocktwits",
		"color" => "40576F",
	),
	"svejo" => array(
		"name" => "Svejo",
		"icon" => "svejo",
		"color" => "5BD428",
	),
	"symbaloo_bookmarks" => array(
		"name" => "Symbaloo Bookmarks",
		"icon" => "symbaloo",
		"color" => "6DA8F7",
	),
	"telegram" => array(
		"name" => "Telegram",
		"icon" => "telegram",
		"color" => "2CA5E0",
	),
	"threema" => array(
		"name" => "Threema",
		"icon" => "threema",
		"color" => "2A2A2A",
	),
	"trello" => array(
		"name" => "Trello",
		"icon" => "trello",
		"color" => "0079BF",
	),
	"tuenti" => array(
		"name" => "Tuenti",
		"icon" => "tuenti",
		"color" => "0075C9",
	),
	"twiddla" => array(
		"name" => "Twiddla",
		"icon" => "twiddla",
		"color" => "2A2A2A",
	),
	"typepad_post" => array(
		"name" => "TypePad Post",
		"icon" => "typepad",
		"color" => "D2DE61",
	),
	"viadeo" => array(
		"name" => "Viadeo",
		"icon" => "viadeo",
		"color" => "2A2A2A",
	),
	"viber" => array(
		"name" => "Viber",
		"icon" => "viber",
		"color" => "7C529E",
	),
	"vk" => array(
		"name" => "VK",
		"icon" => "vk",
		"color" => "587EA3",
	),
	"wanelo" => array(
		"name" => "Wanelo",
		"icon" => "wanelo",
		"color" => "9cb092",
	),
	"wechat" => array(
		"name" => "WeChat",
		"icon" => "wechat",
		"color" => "7BB32E",
	),
	"wordpress" => array(
		"name" => "WordPress",
		"icon" => "wordpress",
		"color" => "464646",
	),
	"wykop" => array(
		"name" => "Wykop",
		"icon" => "wykop",
		"color" => "367DA9",
	),
	"xing" => array(
		"name" => "XING",
		"icon" => "xing",
		"color" => "165B66",
	),
	"yahoo_mail" => array(
		"name" => "Yahoo Mail",
		"icon" => "yahoo",
		"color" => "400090",
	),
	"yoolink" => array(
		"name" => "Yoolink",
		"icon" => "yoolink",
		"color" => "A2C538",
	),
	"yummly" => array(
		"name" => "Yummly",
		"icon" => "yummly",
		"color" => "E16120",
	),

);

$A2A_FOLLOW_services = array(
	
	'facebook' => array( 
		'name' => 'Facebook',
		'href' => 'https://www.facebook.com/${id}',
		'icon' => 'facebook',
		'color' => '3B5998',
	),
	'twitter' => array( 
		'name' => 'Twitter',
		'href' => 'https://twitter.com/${id}',
		'icon' => 'twitter',
		'color' => '55ACEE',
	),
	'instagram' => array( 
		'name' => 'Instagram',
		'href' => 'https://www.instagram.com/${id}',
		'icon' => 'instagram',
		'color' => 'E4405F',
	),
	'pinterest' => array( 
		'name' => 'Pinterest',
		'href' => 'https://www.pinterest.com/${id}',
		'icon' => 'pinterest',
		'color' => 'BD081C',
	),
	'behance' => array( 
		'name' => 'Behance',
		'href' => 'https://www.behance.net/${id}',
		'icon' => 'behance',
		'color' => '007EFF',
	),
	'flickr' => array( 
		'name' => 'Flickr',
		'href' => 'https://www.flickr.com/photos/${id}',
		'icon' => 'flickr',
		'color' => 'FF0084',
	),
	'foursquare' => array( 
		'name' => 'Foursquare',
		'href' => 'https://foursquare.com/${id}',
		'icon' => 'foursquare',
		'color' => 'F94877',
	),
	'github' => array( 
		'name' => 'GitHub',
		'href' => 'https://github.com/${id}',
		'icon' => 'github',
		'color' => '2A2A2A',
	),
	'linkedin' => array( 
		'name' => 'LinkedIn',
		'href' => 'https://www.linkedin.com/in/${id}',
		'icon' => 'linkedin',
		'color' => '007BB5',
	),
	'linkedin_company' => array( 
		'name' => 'LinkedIn Company',
		'href' => 'https://www.linkedin.com/company/${id}',
		'icon' => 'linkedin',
		'color' => '007BB5',
	),
	'medium' => array( 
		'name' => 'Medium',
		'href' => 'https://medium.com/@${id}',
		'icon' => 'medium',
		'color' => '2A2A2A',
	),
	'snapchat' => array( 
		'name' => 'Snapchat',
		'href' => 'https://www.snapchat.com/add/${id}',
		'icon' => 'snapchat',
		'color' => '2A2A2A',
	),
	'tumblr' => array( 
		'name' => 'Tumblr',
		'href' => 'http://${id}.tumblr.com',
		'icon' => 'tumblr',
		'color' => '35465C',
	),
	'vimeo' => array( 
		'name' => 'Vimeo',
		'href' => 'https://vimeo.com/${id}',
		'icon' => 'vimeo',
		'color' => '1AB7EA',
	),
	'youtube' => array( 
		'name' => 'YouTube',
		'href' => 'https://www.youtube.com/user/${id}',
		'icon' => 'youtube',
		'color' => 'FF0000',
	),
	'youtube_channel' => array( 
		'name' => 'YouTube Channel',
		'href' => 'https://www.youtube.com/channel/${id}',
		'icon' => 'youtube',
		'color' => 'FF0000',
	),
	'feed' => array( 
		'name' => 'RSS Feed',
		'href' => 'http://www.example.com/feed/',
		'icon' => 'feed',
		'color' => 'e3702d',
	),
	
);
